﻿-- ############# General Functions #####################

peakboard = {}
-- Get Resource
function peakboard.getresource(path)
	return peakboard.getResource(path)
end

function peakboard.getResource(path)
	return "ts-pbmxdata://resources/" .. path
end

-- Wrapper for the logging method
function peakboard.log(text)
    log(text)
end

-- ############# Control Functions #####################

control = {}
--Toogle the visibility of an element
function control.toggle(control)
	if control.Visibility == Visibility.Collapsed then
	   control.Visibility = Visibility.Visible
	else
		control.Visibility = Visibility.Collapsed
	end
end

-- ############# Number Functions #####################
--Returns a number from a string (tostring wrapper with namespace)
function math.tonumber(num)
    return tonumber(num)
end

-- Round without decimals
function math.roundwithoutdecimals(val)
    return math.roundWithoutDecimals(val)
end

function math.roundWithoutDecimals(val)
	return math.floor(val + 0.5)
end

--Rounds a number to a number with n decimals
function math.roundwithdecimals(val, decimals)
    return math.roundWithDecimals(val, decimals)
end

function math.roundWithDecimals(val, decimals)
	local exp = decimals and 10^decimals or 1
	local result = math.ceil(val * exp - 0.5) / exp
	return result;
end

-- ############# String Functions #####################
--Returns a string of a number (tonumber wrapper with namespace)
function string.tostring(str)
    return tostring(str)
end

--Returns true because 'Hello World' starts with 'He'
function string.startswith(val, start)
    return string.startsWith(val, start)
end

function string.startsWith(val, start)
	return string.sub(val,1,string.len(start))==start
end

--Fill up a string with zeros until it has the size of 18 characters
function string.addleadingcharacters(val, leadingChar, fullLenth)
    return string.AddLeadingCharacters(val, leadingChar, fullLenth)
end

function string.AddLeadingCharacters(val, leadingChar, fullLenth)
	return string.rep(leadingChar, fullLenth - string.len(val)) .. val
end

--Fill up a string with zeros until it has the size of 18 characters
function string.addendingcharacters(val, endingChar, fullLenth)
    return AddEndingCharacters(val, endingChar, fullLenth)
end

function string.AddEndingCharacters(val, endingChar, fullLenth)
	return val .. string.rep(endingChar, fullLenth - string.len(val))
end

-- ############# Table Functions #####################

if not table then
   table = {}
end

-- Sets the background colour of a row
function table.colorrow(evnt, colour)
    table.colorRow(evnt, colour)
end

function table.colorRow(evnt, colour)
	for i = 0, evnt.Columns.Count - 1 do
		evnt.Columns[i].CellControl.Background = colour
	end
end

-- Sets the Text colour of a row
function table.colorrowtext(evnt, colour)
    table.colorRowText(evnt, colour)
end

function table.colorRowText(evnt, colour)
	for i = 0, evnt.Columns.Count - 1 do
		evnt.Columns[i].TextControl.Foreground = colour
	end
end 

-- Gets the Value of a cell
function table.getcelltext(evnt, colIndex)
    return table.getCellText(evnt, colIndex)
end

function table.getCellText(evnt, colIndex)
	return evnt.Columns[colIndex].TextControl.Text
end

-- Sets the value of a cell
function table.setcelltext(evnt, colIndex, newValue)
    table.setCellText(evnt, colIndex, newValue)
end

function table.setCellText(evnt, colIndex, newValue)
	evnt.Columns[colIndex].TextControl.Text = newValue
end

-- ########## Date Functions #############

if not date then
   date = {}
end

function date.parsedatedmy(timeString)
	local pattern = "(%d+).(%d+).(%d+)"
	local nday, nmonth, nyear = timeString:match(pattern)
	return os.time{year = nyear, month = nmonth, day = nday}
end

function date.parsedate(timeString, pattern)
	local nday, nmonth, nyear, nhour, nmin, nsec = timeString:match(pattern)
	return os.time{year = nyear, month = nmonth, day = nday, hour = nhour, min = nmin, sec = nsec}
end

function date.addyear(date, var)
	peakboard.log(date .. '   ' .. var)
	local ndate = date + (var*365*24*60*60)
	peakboard.log(ndate)
	peakboard.log('returned')
	return ndate
end

function date.addday(date, var) 
	local ndate = date + (var*24*60*60)
	return ndate
end

function date.addhour(date, var) 
	local ndate = date + (var*60*60)
	return ndate
end

function date.addminute(date, var) 
	local ndate = date + (var*60)
	return ndate
end

function date.addsecond(date, var) 
	local ndate = date + (var)
	return ndate
end

function date.format(date, pattern)
    return os.date(pattern, date)
end

function date.create(nyear, nmonth, nday)
    return os.time{year=nyear, month=nmonth, day=nday, hour=nhour, min=nmin, sec=nsec}
end

function date.create(nyear, nmonth, nday, nhour, nmin, nsec)
    return os.time{year=nyear, month=nmonth, day=nday, hour=nhour, min=nmin, sec=nsec}
end

function date.difference(date1, date2)
    return os.difftime (date1, date2)
end